Genotations
===========

Python library to work with genomes and annotations, mostly Ensembl genomes. Also supports visualization of transcripts/gene features and primer selection.

Setup
=====

Use micromamba and environment.yaml to install the dependencies

TODO: documentation is in proccess